==> AnyChart-Android-1.0.3-sources.jar: com/anychart/AnyChart.java <==
package com.anychart;

public class AnyChart {

    public static com.anychart.charts.Cartesian area() {
        return new com.anychart.charts.Cartesian("anychart.area()");
    }

    public static com.anychart.charts.Cartesian3d area3d() {
        return new com.anychart.charts.Cartesian3d("anychart.area3d()");
    }

    public static com.anychart.charts.Cartesian bar() {
        return new com.anychart.charts.Cartesian("anychart.bar()");
    }

    public static com.anychart.charts.Cartesian3d bar3d() {
        return new com.anychart.charts.Cartesian3d("anychart.bar3d()");
    }

    public static com.anychart.charts.Mekko barmekko() {
        return new com.anychart.charts.Mekko("anychart.barmekko()");
    }

    public static com.anychart.charts.Cartesian box() {
        return new com.anychart.charts.Cartesian("anychart.box()");
    }

    public static com.anychart.charts.Scatter bubble() {
        return new com.anychart.charts.Scatter("anychart.bubble()");
    }

    public static com.anychart.charts.Map bubbleMap() {
        return new com.anychart.charts.Map("anychart.bubbleMap()");
    }

    public static com.anychart.charts.Bullet bullet() {
        return new com.anychart.charts.Bullet("anychart.bullet()");
    }

    public static com.anychart.charts.Cartesian cartesian() {
        return new com.anychart.charts.Cartesian("anychart.cartesian()");
    }

    public static com.anychart.charts.Cartesian3d cartesian3d() {
        return new com.anychart.charts.Cartesian3d("anychart.cartesian3d()");
    }

    public static com.anychart.charts.Map choropleth() {
        return new com.anychart.charts.Map("anychart.choropleth()");
    }

    public static com.anychart.charts.CircularGauge circularGauge() {
        return new com.anychart.charts.CircularGauge("anychart.circularGauge()");
    }

    public static com.anychart.charts.Cartesian column() {
        return new com.anychart.charts.Cartesian("anychart.column()");
    }

    public static com.anychart.charts.Cartesian3d column3d() {
        return new com.anychart.charts.Cartesian3d("anychart.column3d()");
    }

    public static com.anychart.charts.Map connector() {
        return new com.anychart.charts.Map("anychart.connector()");
    }

    public static com.anychart.charts.Cartesian financial() {
        return new com.anychart.charts.Cartesian("anychart.financial()");
    }

    public static com.anychart.charts.Funnel funnel() {
        return new com.anychart.charts.Funnel("anychart.funnel()");
    }

    public static com.anychart.charts.Gantt ganttProject() {
        return new com.anychart.charts.Gantt("anychart.ganttProject()");
    }

    public static com.anychart.charts.Gantt ganttResource() {
        return new com.anychart.charts.Gantt("anychart.ganttResource()");
    }

    public static com.anychart.charts.HeatMap heatMap() {
        return new com.anychart.charts.HeatMap("anychart.heatMap()");
    }

    public static com.anychart.charts.Cartesian hilo() {
        return new com.anychart.charts.Cartesian("anychart.hilo()");
    }

    public static com.anychart.charts.Cartesian line() {
        return new com.anychart.charts.Cartesian("anychart.line()");
    }

    public static com.anychart.charts.Cartesian3d line3d() {
        return new com.anychart.charts.Cartesian3d("anychart.line3d()");
    }

    public static com.anychart.charts.Map map() {
        return new com.anychart.charts.Map("anychart.map()");
    }

    public static com.anychart.charts.Scatter marker() {
        return new com.anychart.charts.Scatter("anychart.marker()");
    }

    public static com.anychart.charts.Map markerMap() {
        return new com.anychart.charts.Map("anychart.markerMap()");
    }

    public static com.anychart.charts.Mekko mekko() {
        return new com.anychart.charts.Mekko("anychart.mekko()");
    }

    public static com.anychart.charts.Mekko mosaic() {
        return new com.anychart.charts.Mekko("anychart.mosaic()");
    }

    public static com.anychart.charts.Pareto pareto() {
        return new com.anychart.charts.Pareto("anychart.pareto()");
    }

    public static com.anychart.charts.Pert pert() {
        return new com.anychart.charts.Pert("anychart.pert()");
    }

    public static com.anychart.charts.Pie pie() {
        return new com.anychart.charts.Pie("anychart.pie()");
    }

    public static com.anychart.charts.Pie pie3d() {
        return new com.anychart.charts.Pie("anychart.pie3d()");
    }

    public static com.anychart.charts.Polar polar() {
        return new com.anychart.charts.Polar("anychart.polar()");
    }

    public static com.anychart.charts.Pyramid pyramid() {
        return new com.anychart.charts.Pyramid("anychart.pyramid()");
    }

    public static com.anychart.charts.Scatter quadrant() {
        return new com.anychart.charts.Scatter("anychart.quadrant()");
    }

    public static com.anychart.charts.Radar radar() {
        return new com.anychart.charts.Radar("anychart.radar()");
    }

    public static com.anychart.charts.Resource resource() {
        return new com.anychart.charts.Resource("anychart.resource()");
    }

    public static com.anychart.charts.Scatter scatter() {
        return new com.anychart.charts.Scatter("anychart.scatter()");
    }

    public static com.anychart.charts.Map seatMap() {
        return new com.anychart.charts.Map("anychart.seatMap()");
    }

    public static com.anychart.charts.Sparkline sparkline() {
        return new com.anychart.charts.Sparkline("anychart.sparkline()");
    }

    public static com.anychart.charts.Stock stock() {
        return new com.anychart.charts.Stock("anychart.stock()");
    }

    public static com.anychart.charts.Sunburst sunburst() {
        return new com.anychart.charts.Sunburst("anychart.sunburst()");
    }

    public static com.anychart.charts.TagCloud tagCloud() {
        return new com.anychart.charts.TagCloud("anychart.tagCloud()");
    }

    public static com.anychart.charts.TreeMap treeMap() {
        return new com.anychart.charts.TreeMap("anychart.treeMap()");
    }

    public static com.anychart.charts.Venn venn() {
        return new com.anychart.charts.Venn("anychart.venn()");
    }

    public static com.anychart.charts.Cartesian vertical() {
        return new com.anychart.charts.Cartesian("anychart.vertical()");
    }

    public static com.anychart.charts.Cartesian verticalArea() {
        return new com.anychart.charts.Cartesian("anychart.verticalArea()");
    }

    public static com.anychart.charts.Cartesian verticalLine() {
        return new com.anychart.charts.Cartesian("anychart.verticalLine()");
    }

    public static com.anychart.charts.Waterfall waterfall() {
        return new com.anychart.charts.Waterfall("anychart.waterfall()");
    }

    public static com.anychart.charts.CircularGauge circular() {
        return new com.anychart.charts.CircularGauge("anychart.gauges.circular()");
    }

    public static com.anychart.charts.LinearGauge led() {
        return new com.anychart.charts.LinearGauge("anychart.gauges.led()");
    }

    public static com.anychart.charts.LinearGauge linear() {
        return new com.anychart.charts.LinearGauge("anychart.gauges.linear()");
    }

    public static com.anychart.charts.LinearGauge tank() {
        return new com.anychart.charts.LinearGauge("anychart.gauges.tank()");
    }

    public static com.anychart.charts.LinearGauge thermometer() {
        return new com.anychart.charts.LinearGauge("anychart.gauges.thermometer()");
    }


}

==> AnyChart-Android-1.0.7-sources.jar: com/anychart/AnyChart.java <==
package com.anychart;

public class AnyChart {

    public static com.anychart.charts.Cartesian area() {
        return new com.anychart.charts.Cartesian("anychart.area()");
    }

    public static com.anychart.charts.Cartesian3d area3d() {
        return new com.anychart.charts.Cartesian3d("anychart.area3d()");
    }

    public static com.anychart.charts.Cartesian bar() {
        return new com.anychart.charts.Cartesian("anychart.bar()");
    }

    public static com.anychart.charts.Cartesian3d bar3d() {
        return new com.anychart.charts.Cartesian3d("anychart.bar3d()");
    }

    public static com.anychart.charts.Mekko barmekko() {
        return new com.anychart.charts.Mekko("anychart.barmekko()");
    }

    public static com.anychart.charts.Cartesian box() {
        return new com.anychart.charts.Cartesian("anychart.box()");
    }

    public static com.anychart.charts.Scatter bubble() {
        return new com.anychart.charts.Scatter("anychart.bubble()");
    }

    public static com.anychart.charts.Map bubbleMap() {
        return new com.anychart.charts.Map("anychart.bubbleMap()");
    }

    public static com.anychart.charts.Bullet bullet() {
        return new com.anychart.charts.Bullet("anychart.bullet()");
    }

    public static com.anychart.charts.Cartesian cartesian() {
        return new com.anychart.charts.Cartesian("anychart.cartesian()");
    }

    public static com.anychart.charts.Cartesian3d cartesian3d() {
        return new com.anychart.charts.Cartesian3d("anychart.cartesian3d()");
    }

    public static com.anychart.charts.Map choropleth() {
        return new com.anychart.charts.Map("anychart.choropleth()");
    }

    public static com.anychart.charts.CircularGauge circularGauge() {
        return new com.anychart.charts.CircularGauge("anychart.circularGauge()");
    }

    public static com.anychart.charts.Cartesian column() {
        return new com.anychart.charts.Cartesian("anychart.column()");
    }

    public static com.anychart.charts.Cartesian3d column3d() {
        return new com.anychart.charts.Cartesian3d("anychart.column3d()");
    }

    public static com.anychart.charts.Map connector() {
        return new com.anychart.charts.Map("anychart.connector()");
    }

    public static com.anychart.charts.Cartesian financial() {
        return new com.anychart.charts.Cartesian("anychart.financial()");
    }

    public static com.anychart.charts.Funnel funnel() {
        return new com.anychart.charts.Funnel("anychart.funnel()");
    }

    public static com.anychart.charts.Gantt ganttProject() {
        return new com.anychart.charts.Gantt("anychart.ganttProject()");
    }

    public static com.anychart.charts.Gantt ganttResource() {
        return new com.anychart.charts.Gantt("anychart.ganttResource()");
    }

    public static com.anychart.charts.HeatMap heatMap() {
        return new com.anychart.charts.HeatMap("anychart.heatMap()");
    }

    public static com.anychart.charts.Cartesian hilo() {
        return new com.anychart.charts.Cartesian("anychart.hilo()");
    }

    public static com.anychart.charts.Cartesian line() {
        return new com.anychart.charts.Cartesian("anychart.line()");
    }

    public static com.anychart.charts.Cartesian3d line3d() {
        return new com.anychart.charts.Cartesian3d("anychart.line3d()");
    }

    public static com.anychart.charts.Map map() {
        return new com.anychart.charts.Map("anychart.map()");
    }

    public static com.anychart.charts.Scatter marker() {
        return new com.anychart.charts.Scatter("anychart.marker()");
    }

    public static com.anychart.charts.Map markerMap() {
        return new com.anychart.charts.Map("anychart.markerMap()");
    }

    public static com.anychart.charts.Mekko mekko() {
        return new com.anychart.charts.Mekko("anychart.mekko()");
    }

    public static com.anychart.charts.Mekko mosaic() {
        return new com.anychart.charts.Mekko("anychart.mosaic()");
    }

    public static com.anychart.charts.Pareto pareto() {
        return new com.anychart.charts.Pareto("anychart.pareto()");
    }

    public static com.anychart.charts.Pert pert() {
        return new com.anychart.charts.Pert("anychart.pert()");
    }

    public static com.anychart.charts.Pie pie() {
        return new com.anychart.charts.Pie("anychart.pie()");
    }

    public static com.anychart.charts.Pie pie3d() {
        return new com.anychart.charts.Pie("anychart.pie3d()");
    }

    public static com.anychart.charts.Polar polar() {
        return new com.anychart.charts.Polar("anychart.polar()");
    }

    public static com.anychart.charts.Pyramid pyramid() {
        return new com.anychart.charts.Pyramid("anychart.pyramid()");
    }

    public static com.anychart.charts.Scatter quadrant() {
        return new com.anychart.charts.Scatter("anychart.quadrant()");
    }

    public static com.anychart.charts.Radar radar() {
        return new com.anychart.charts.Radar("anychart.radar()");
    }

    public static com.anychart.charts.Resource resource() {
        return new com.anychart.charts.Resource("anychart.resource()");
    }

    public static com.anychart.charts.Sankey sankey() {
        return new com.anychart.charts.Sankey("anychart.sankey()");
    }

    public static com.anychart.charts.Scatter scatter() {
        return new com.anychart.charts.Scatter("anychart.scatter()");
    }

    public static com.anychart.charts.Map seatMap() {
        return new com.anychart.charts.Map("anychart.seatMap()");
    }

    public static com.anychart.charts.Sparkline sparkline() {
        return new com.anychart.charts.Sparkline("anychart.sparkline()");
    }

    public static com.anychart.charts.Stock stock() {
        return new com.anychart.charts.Stock("anychart.stock()");
    }

    public static com.anychart.charts.Sunburst sunburst() {
        return new com.anychart.charts.Sunburst("anychart.sunburst()");
    }

    public static com.anychart.charts.TagCloud tagCloud() {
        return new com.anychart.charts.TagCloud("anychart.tagCloud()");
    }

    public static com.anychart.charts.TreeMap treeMap() {
        return new com.anychart.charts.TreeMap("anychart.treeMap()");
    }

    public static com.anychart.charts.Venn venn() {
        return new com.anychart.charts.Venn("anychart.venn()");
    }

    public static com.anychart.charts.Cartesian vertical() {
        return new com.anychart.charts.Cartesian("anychart.vertical()");
    }

    public static com.anychart.charts.Cartesian verticalArea() {
        return new com.anychart.charts.Cartesian("anychart.verticalArea()");
    }

    public static com.anychart.charts.Cartesian verticalLine() {
        return new com.anychart.charts.Cartesian("anychart.verticalLine()");
    }

    public static com.anychart.charts.Waterfall waterfall() {
        return new com.anychart.charts.Waterfall("anychart.waterfall()");
    }

    public static com.anychart.charts.CircularGauge circular() {
        return new com.anychart.charts.CircularGauge("anychart.gauges.circular()");
    }

    public static com.anychart.charts.LinearGauge led() {
        return new com.anychart.charts.LinearGauge("anychart.gauges.led()");
    }

    public static com.anychart.charts.LinearGauge linear() {
        return new com.anychart.charts.LinearGauge("anychart.gauges.linear()");
    }

    public static com.anychart.charts.LinearGauge tank() {
        return new com.anychart.charts.LinearGauge("anychart.gauges.tank()");
    }

    public static com.anychart.charts.LinearGauge thermometer() {
        return new com.anychart.charts.LinearGauge("anychart.gauges.thermometer()");
    }


}
